@@ -31,16 +31,16 @@ def error_callback(retry_state):
 
 class AIS:
     retry_options = {
-        "stop": stop_after_attempt(7),
+        "stop": stop_after_attempt(10),
         "wait": wait_fixed(15),
         "after": before_retry,
         "retry_error_callback": error_callback
     }
     def __init__(self, proxy=False, verbose=False, columns="all", columns_excluded=None, print_query = False,
-                 num_retries=7, seconds_wait=15, filter_config=None, return_df=False, return_total_count=False,
+                 num_retries=10, seconds_wait=15, filter_config=None, return_df=False, return_total_count=False,
                  **proxy_config):
         # Setting Retry Options
-        if num_retries != 7:
+        if num_retries != 10:
             AIS.retry_options['stop'] = stop_after_attempt(num_retries)
         if seconds_wait != 15:
             AIS.retry_options['wait'] = wait_fixed(seconds_wait)
@@ -52,8 +52,7 @@ class AIS:
         self.columns_excluded = columns_excluded
         self.print_query = print_query
         self.session = requests.Session()
-        if filter_config is not None:
-            self.filters = Filters(**filter_config)
+        self.set_filters(filter_config)
         self.session.headers.update({
             'user-agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:93.0) Gecko/20100101 Firefox/93.0',
             'Vessel-Image': '005bf958a6548a79c6d3a42eba493e339624',
@@ -72,6 +71,9 @@ class AIS:
         else:
             self.proxy = False
 
+    def set_filters(self, filter_config):
+        self.filters = Filters(**filter_config)
+
     def set_column_url(self):
         possible_columns = ["time_of_latest_position", "flag", "shipname", "photo", "recognized_next_port",
                             "reported_eta", "reported_destination", "current_port", "imo", "mmsi", "ship_type",
@@ -129,7 +131,7 @@ class AIS:
         self.session.proxies = self.freeproxy.get()
         self.verbose_print("Proxy found...")
 
-    #@retry(**retry_options)
+    @retry(**retry_options)
     def get_area_data(self, area):
         possible_areas = {
             "ADRIA":	"Adriatic Sea",
@@ -199,10 +201,11 @@ class AIS:
                       f"&area_in|in|{areas_long}|area_in={area_short}{self.filters.to_query(ignore_filter='global_area')}"
         referer_url = f"https://www.marinetraffic.com/en/data/?asset_type=vessels&columns={self.columns_url}" \
                       f"&area_in|in|{areas_long}|area_in={area_short}{self.filters.to_query(ignore_filter='global_area')}"
-        self.query_print(referer_url)
+        self.query_print("referer_url: " + referer_url)
+        self.query_print("request_url: " + request_url)
         return self.return_response(request_url, referer_url)
 
-    #@retry(**retry_options)
+    @retry(**retry_options)
     def get_location(self, mmsi):
         if isinstance(mmsi, int):
             mmsi = str(mmsi)
@@ -210,7 +213,8 @@ class AIS:
                       f"&mmsi|eq|mmsi={mmsi}{self.filters.to_query(ignore_filter='mmsi')}"
         referer_url = f"https://www.marinetraffic.com/en/data/?asset_type=vessels&columns={self.columns_url}" \
                       f"&mmsi|eq|mmsi={mmsi}{self.filters.to_query(ignore_filter='mmsi')}"
-        self.query_print(referer_url)
+        self.query_print("referer_url: " + referer_url)
+        self.query_print("request_url: " + request_url)
         return self.return_response(request_url, referer_url)
 
     @retry(**retry_options)
@@ -249,4 +253,4 @@ class AIS:
             title = titles[0].text_content()
             if "Cloudflare" in title:
                 self.verbose_print(f"Cloudflare has detected unusual behavior. Changing Proxy...")
-                raise CloudflareError()
+                raise CloudflareError()
\ No newline at end of file
